(* file: checks.ml
 * author: Bob Muller
 *
 * A program for rendering an N x N checkerboard.
 *
 * Usage: in a Unix shell, type:
 *
 * > make
 * > ./checks
 *)
open World
open Image
open Color

open Cs1101

let displayWidth = 800.
let displayHeight = displayWidth

(* rowOfChecks : int -> Color.t -> Image.t
 *)
let rowOfChecks n side =
  let emptyRow = Image.empty_scene displayWidth side in
  let rec repeat m image =
    match m = 0 with
    | true  -> image
    | false -> let color = Cs1101.randomColor() in
	       let check = Image.rectangle side side color in
	       let y = 0.0 in
	       let x = (float (m - 1)) *. side in
	       let newImage = Image.place_image check (x, y) image
	       in
	       repeat (m - 1) newImage
  in
  repeat n emptyRow

let checks n =
  let side = displayWidth /. (float n) in
  let empty = Image.empty_scene displayWidth displayHeight in
  let rec manyRows row image =
    match row = 0 with
    | true  -> image
    | false -> let checkRow = rowOfChecks n side in
	       let y = (float (row - 1)) *. side in
	       let x = 0.0 in
	       let newImage = Image.place_image checkRow (x, y) image
	       in
	       manyRows (row - 1) newImage
  in
  manyRows n empty

(* go : unit -> Image.t
 *
 * This function will be called once every second by the World.big_bang
 * function.
 *)
let go () = checks 8

let _ = World.big_bang ()
		       ~name:"Stripes!"
		       ~width: (int_of_float displayWidth)
		       ~height:(int_of_float displayHeight)
		       ~to_draw:go
