(* file: pi.ml
 * author: Bob Muller
 *
 * CS1101 Computer Science I
 *
 * The Monte Carlo Method for approximating pi.
 *
 * The idea is to generate N random points in the unit square. Those
 * within a distance of 1 from the origin fall within the upper right
 * quarter of a unit circle. For sufficiently large N, we expect pi/4
 * of them to fall within the quartercircle.
 *
 * approxPi : int -> float
 *)
let approxPi n =
  let rec repeat i inside =
    match i > n with
    | true  -> (float inside) /. (float n) *. 4.0
    | false -> let x = Random.float 1.0 in 
	       let y = Random.float 1.0 in
	       match (sqrt (x ** 2.0 +. y ** 2.0)) < 1.0 with
	       | true  -> repeat (i + 1) (inside + 1)
	       | false -> repeat (i + 1) inside
  in
  repeat 1 0
